enum PhysicalType {
Boolean,
Int32,
Int64,
Float,
Double,
ByteArray,
FixedLenByteArray,
}Expand description
Parquet physical types used while selecting the code emitted by the macro.
Keeping this local avoids compiling parquet for the proc-macro host.
Variants